Documentation
¶
Overview ¶
Package ingress exposes the interface the controller needs to operate on Ingress resources.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Fake ¶
type Fake struct {
// contains filtered or unexported fields
}
type Interface ¶
type Interface interface {
// Get fetches the resource identified by id.
Get(id typesutils.Id) (*v1.Ingress, error)
// HasSynced is true after first batch of Ingress resources
// defined in the cluster has been synchronized with
// the local storage.
HasSynced() bool
// List returns all Ingress resources.
List() ([]*v1.Ingress, error)
// Patch patches `patchBytes` changes to the ingress resource with the given id.
Patch(ctx context.Context, id typesutils.Id, patchBytes []byte) error
// Run initializes the object exposing the Ingress API.
Run(ctx context.Context, queue workqueue.RateLimitingInterface)
}
Interface defines the interface the controller needs to operate on Ingress resources.
func New ¶
func New(clientset *kubernetes.Clientset) Interface
Click to show internal directories.
Click to hide internal directories.